@@ -14,7 +14,7 @@
    +----------------------------------------------------------------------+
 */
 
-#define CONFIGURE_COMMAND " './configure'  'ax_cv_have_func_attribute_ifunc=no' '--with-config-file-path=/usr/pkg/etc' '--with-config-file-scan-dir=/usr/pkg/etc/php.d' '--sysconfdir=/usr/pkg/etc' '--localstatedir=/var' '--without-mysqli' '--without-iconv' '--without-pear' '--without-sqlite3' '--with-external-pcre' '--disable-intl' '--disable-posix' '--disable-opcache' '--disable-pdo' '--enable-cgi' '--enable-mysqlnd' '--enable-xml' '--enable-ipv6' '--with-openssl=/usr' '--with-readline=/usr/pkg' '--prefix=/usr/pkg' '--build=m68k--netbsdelf' '--host=m68k--netbsdelf' '--mandir=/usr/pkg/man' '--enable-option-checking=yes' 'build_alias=m68k--netbsdelf' 'host_alias=m68k--netbsdelf' 'PKG_CONFIG=/usr/pkg/bin/pkg-config' 'PKG_CONFIG_PATH=' 'PKG_CONFIG_LIBDIR=/usr/pkg/lib/pkgconfig:/usr/pkg/share/pkgconfig:/usr/lib/pkgconfig:/usr/X11R7/lib/pkgconfig' 'LIBS='"
+#define CONFIGURE_COMMAND " './configure'  'ax_cv_have_func_attribute_ifunc=no' '--with-config-file-path=/usr/pkg/etc' '--with-config-file-scan-dir=/usr/pkg/etc/php.d' '--sysconfdir=/usr/pkg/etc' '--localstatedir=/var' '--without-mysqli' '--without-iconv' '--without-pear' '--without-sqlite3' '--with-external-pcre' '--disable-intl' '--disable-posix' '--disable-opcache' '--disable-pdo' '--enable-cgi' '--enable-mysqlnd' '--enable-xml' '--enable-ipv6' '--with-openssl=/usr' '--with-readline=/usr/pkg' '--prefix=/usr/pkg' '--build=alpha--netbsd' '--host=alpha--netbsd' '--mandir=/usr/pkg/man' '--enable-option-checking=yes' 'build_alias=alpha--netbsd' 'host_alias=alpha--netbsd' 'PKG_CONFIG=/usr/pkg/bin/pkg-config' 'PKG_CONFIG_PATH=' 'PKG_CONFIG_LIBDIR=/usr/pkg/lib/pkgconfig:/usr/pkg/share/pkgconfig:/usr/lib/pkgconfig:/usr/X11R7/lib/pkgconfig' 'LIBS='"
 #define PHP_ODBC_CFLAGS	""
 #define PHP_ODBC_LFLAGS		""
 #define PHP_ODBC_LIBS		""
@@ -24,7 +24,7 @@
 #define PHP_PROG_SENDMAIL	"/usr/sbin/sendmail"
 #define PEAR_INSTALLDIR         ""
 #define PHP_INCLUDE_PATH	".:"
-#define PHP_EXTENSION_DIR       "/usr/pkg/lib/php/20211125"
+#define PHP_EXTENSION_DIR       "/usr/pkg/lib/php/20220829"
 #define PHP_PREFIX              "/usr/pkg"
 #define PHP_BINDIR              "/usr/pkg/bin"
 #define PHP_SBINDIR             "/usr/pkg/sbin"
